from QuranDownloader.verse_key_converters import *
from QuranDownloader.consts import *
from QuranDownloader.download_word import download_word
from QuranDownloader.download_verse import download_verse


# download_word(verse_key='1:5', export_dir='./export/words')