RECITERS = ['AbdulBaset_Mujawwad', 'AbdulBaset_Murattal', 'Sudais', 'Shatri', 'Rifai', 'Husary',
            'Alafasy', 'Minshawi_Mujawwad', 'Minshawi_Murattal', 'Shuraym', 'Mohammad_al_Tablaway', 'Husary_Muallim']
SHIKS_LIMITS = [1, 13]
FILTERS = ['chapter_number', 'juz_number', 'page_number', 'verse_key']
API_URL = 'https://verses.quran.com'
RECITATIONS_URL = 'https://api.quran.com/api/v4/quran/recitations'